# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: c3loc/proto/location.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='c3loc/proto/location.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x63\x33loc/proto/location.proto\"\xec\x02\n\x0eIBeaconSummary\x12\r\n\x05\x63lock\x18\x01 \x01(\x04\x12.\n\x07reports\x18\x02 \x03(\x0b\x32\x1d.IBeaconSummary.IBeaconReport\x1a\x9a\x02\n\rIBeaconReport\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x11\n\tmajor_num\x18\x02 \x01(\r\x12\x11\n\tminor_num\x18\x03 \x01(\r\x12\x13\n\x0b\x64istance_cm\x18\x04 \x01(\r\x12\x10\n\x08variance\x18\x05 \x01(\r\x12\r\n\x05\x63ount\x18\x06 \x01(\r\x12\x39\n\x06reason\x18\x07 \x01(\x0e\x32).IBeaconSummary.IBeaconReport.EventReason\x12\x0e\n\x06median\x18\x08 \x01(\r\x12\x0c\n\x04mode\x18\t \x01(\r\"F\n\x0b\x45ventReason\x12\x0c\n\x08RESERVED\x10\x00\x12\t\n\x05\x45NTRY\x10\x01\x12\x08\n\x04\x45XIT\x10\x02\x12\x08\n\x04MOVE\x10\x03\x12\n\n\x06STATUS\x10\x04\"\xfc\x02\n\x11TempBeaconSummary\x12\r\n\x05\x63lock\x18\x01 \x01(\x04\x12\x34\n\x07reports\x18\x02 \x03(\x0b\x32#.TempBeaconSummary.TempBeaconReport\x1a\xa1\x02\n\x10TempBeaconReport\x12\x11\n\tbeacon_id\x18\x01 \x01(\x0c\x12\x0c\n\x04temp\x18\x02 \x01(\r\x12\x0f\n\x07\x62\x61ttery\x18\x03 \x01(\r\x12\x13\n\x0b\x64istance_cm\x18\x04 \x01(\r\x12\x10\n\x08variance\x18\x05 \x01(\r\x12\r\n\x05\x63ount\x18\x06 \x01(\r\x12?\n\x06reason\x18\x07 \x01(\x0e\x32/.TempBeaconSummary.TempBeaconReport.EventReason\x12\x0e\n\x06median\x18\x08 \x01(\r\x12\x0c\n\x04mode\x18\t \x01(\r\"F\n\x0b\x45ventReason\x12\x0c\n\x08RESERVED\x10\x00\x12\t\n\x05\x45NTRY\x10\x01\x12\x08\n\x04\x45XIT\x10\x02\x12\x08\n\x04MOVE\x10\x03\x12\n\n\x06STATUS\x10\x04\"\xb6\x04\n\x0fLABeaconSummary\x12\r\n\x05\x63lock\x18\x01 \x01(\x04\x12\x30\n\x07reports\x18\x02 \x03(\x0b\x32\x1f.LABeaconSummary.LABeaconReport\x1a\xe1\x03\n\x0eLABeaconReport\x12\x11\n\tbeacon_id\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x0f\n\x07nearest\x18\x03 \x01(\r\x12\x14\n\x0cnearest_dist\x18\x04 \x01(\r\x12\x15\n\rnearest_delta\x18\x05 \x01(\r\x12\x13\n\x0b\x64istance_cm\x18\x06 \x01(\r\x12\x10\n\x08variance\x18\x07 \x01(\r\x12\r\n\x05\x63ount\x18\x08 \x01(\r\x12;\n\x06reason\x18\t \x01(\x0e\x32+.LABeaconSummary.LABeaconReport.EventReason\x12\x0e\n\x06median\x18\n \x01(\r\x12\x0c\n\x04mode\x18\x0b \x01(\r\x12\x13\n\x0b\x62\x61ttery_pct\x18\x0c \x01(\r\x12<\n\x06status\x18\r \x01(\x0e\x32,.LABeaconSummary.LABeaconReport.ButtonStatus\"F\n\x0b\x45ventReason\x12\x0c\n\x08RESERVED\x10\x00\x12\t\n\x05\x45NTRY\x10\x01\x12\x08\n\x04\x45XIT\x10\x02\x12\x08\n\x04MOVE\x10\x03\x12\n\n\x06STATUS\x10\x04\"?\n\x0c\x42uttonStatus\x12\x11\n\rNOT_AVAILABLE\x10\x00\x12\x0f\n\x0bNOT_PRESSED\x10\x01\x12\x0b\n\x07PRESSED\x10\x02\x62\x06proto3'
)



_IBEACONSUMMARY_IBEACONREPORT_EVENTREASON = _descriptor.EnumDescriptor(
  name='EventReason',
  full_name='IBeaconSummary.IBeaconReport.EventReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENTRY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=325,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_IBEACONSUMMARY_IBEACONREPORT_EVENTREASON)

_TEMPBEACONSUMMARY_TEMPBEACONREPORT_EVENTREASON = _descriptor.EnumDescriptor(
  name='EventReason',
  full_name='TempBeaconSummary.TempBeaconReport.EventReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENTRY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=325,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_TEMPBEACONSUMMARY_TEMPBEACONREPORT_EVENTREASON)

_LABEACONSUMMARY_LABEACONREPORT_EVENTREASON = _descriptor.EnumDescriptor(
  name='EventReason',
  full_name='LABeaconSummary.LABeaconReport.EventReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENTRY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=325,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_LABEACONSUMMARY_LABEACONREPORT_EVENTREASON)

_LABEACONSUMMARY_LABEACONREPORT_BUTTONSTATUS = _descriptor.EnumDescriptor(
  name='ButtonStatus',
  full_name='LABeaconSummary.LABeaconReport.ButtonStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_AVAILABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_PRESSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1284,
  serialized_end=1347,
)
_sym_db.RegisterEnumDescriptor(_LABEACONSUMMARY_LABEACONREPORT_BUTTONSTATUS)


_IBEACONSUMMARY_IBEACONREPORT = _descriptor.Descriptor(
  name='IBeaconReport',
  full_name='IBeaconSummary.IBeaconReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='IBeaconSummary.IBeaconReport.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='major_num', full_name='IBeaconSummary.IBeaconReport.major_num', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor_num', full_name='IBeaconSummary.IBeaconReport.minor_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_cm', full_name='IBeaconSummary.IBeaconReport.distance_cm', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variance', full_name='IBeaconSummary.IBeaconReport.variance', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='IBeaconSummary.IBeaconReport.count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='IBeaconSummary.IBeaconReport.reason', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='median', full_name='IBeaconSummary.IBeaconReport.median', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='IBeaconSummary.IBeaconReport.mode', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IBEACONSUMMARY_IBEACONREPORT_EVENTREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=395,
)

_IBEACONSUMMARY = _descriptor.Descriptor(
  name='IBeaconSummary',
  full_name='IBeaconSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clock', full_name='IBeaconSummary.clock', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='IBeaconSummary.reports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IBEACONSUMMARY_IBEACONREPORT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=395,
)


_TEMPBEACONSUMMARY_TEMPBEACONREPORT = _descriptor.Descriptor(
  name='TempBeaconReport',
  full_name='TempBeaconSummary.TempBeaconReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='TempBeaconSummary.TempBeaconReport.beacon_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp', full_name='TempBeaconSummary.TempBeaconReport.temp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery', full_name='TempBeaconSummary.TempBeaconReport.battery', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_cm', full_name='TempBeaconSummary.TempBeaconReport.distance_cm', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variance', full_name='TempBeaconSummary.TempBeaconReport.variance', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='TempBeaconSummary.TempBeaconReport.count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='TempBeaconSummary.TempBeaconReport.reason', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='median', full_name='TempBeaconSummary.TempBeaconReport.median', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='TempBeaconSummary.TempBeaconReport.mode', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TEMPBEACONSUMMARY_TEMPBEACONREPORT_EVENTREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=778,
)

_TEMPBEACONSUMMARY = _descriptor.Descriptor(
  name='TempBeaconSummary',
  full_name='TempBeaconSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clock', full_name='TempBeaconSummary.clock', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='TempBeaconSummary.reports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TEMPBEACONSUMMARY_TEMPBEACONREPORT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=778,
)


_LABEACONSUMMARY_LABEACONREPORT = _descriptor.Descriptor(
  name='LABeaconReport',
  full_name='LABeaconSummary.LABeaconReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='LABeaconSummary.LABeaconReport.beacon_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='LABeaconSummary.LABeaconReport.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nearest', full_name='LABeaconSummary.LABeaconReport.nearest', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nearest_dist', full_name='LABeaconSummary.LABeaconReport.nearest_dist', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nearest_delta', full_name='LABeaconSummary.LABeaconReport.nearest_delta', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_cm', full_name='LABeaconSummary.LABeaconReport.distance_cm', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variance', full_name='LABeaconSummary.LABeaconReport.variance', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='LABeaconSummary.LABeaconReport.count', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='LABeaconSummary.LABeaconReport.reason', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='median', full_name='LABeaconSummary.LABeaconReport.median', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='LABeaconSummary.LABeaconReport.mode', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_pct', full_name='LABeaconSummary.LABeaconReport.battery_pct', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='LABeaconSummary.LABeaconReport.status', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LABEACONSUMMARY_LABEACONREPORT_EVENTREASON,
    _LABEACONSUMMARY_LABEACONREPORT_BUTTONSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=1347,
)

_LABEACONSUMMARY = _descriptor.Descriptor(
  name='LABeaconSummary',
  full_name='LABeaconSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clock', full_name='LABeaconSummary.clock', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='LABeaconSummary.reports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LABEACONSUMMARY_LABEACONREPORT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=781,
  serialized_end=1347,
)

_IBEACONSUMMARY_IBEACONREPORT.fields_by_name['reason'].enum_type = _IBEACONSUMMARY_IBEACONREPORT_EVENTREASON
_IBEACONSUMMARY_IBEACONREPORT.containing_type = _IBEACONSUMMARY
_IBEACONSUMMARY_IBEACONREPORT_EVENTREASON.containing_type = _IBEACONSUMMARY_IBEACONREPORT
_IBEACONSUMMARY.fields_by_name['reports'].message_type = _IBEACONSUMMARY_IBEACONREPORT
_TEMPBEACONSUMMARY_TEMPBEACONREPORT.fields_by_name['reason'].enum_type = _TEMPBEACONSUMMARY_TEMPBEACONREPORT_EVENTREASON
_TEMPBEACONSUMMARY_TEMPBEACONREPORT.containing_type = _TEMPBEACONSUMMARY
_TEMPBEACONSUMMARY_TEMPBEACONREPORT_EVENTREASON.containing_type = _TEMPBEACONSUMMARY_TEMPBEACONREPORT
_TEMPBEACONSUMMARY.fields_by_name['reports'].message_type = _TEMPBEACONSUMMARY_TEMPBEACONREPORT
_LABEACONSUMMARY_LABEACONREPORT.fields_by_name['reason'].enum_type = _LABEACONSUMMARY_LABEACONREPORT_EVENTREASON
_LABEACONSUMMARY_LABEACONREPORT.fields_by_name['status'].enum_type = _LABEACONSUMMARY_LABEACONREPORT_BUTTONSTATUS
_LABEACONSUMMARY_LABEACONREPORT.containing_type = _LABEACONSUMMARY
_LABEACONSUMMARY_LABEACONREPORT_EVENTREASON.containing_type = _LABEACONSUMMARY_LABEACONREPORT
_LABEACONSUMMARY_LABEACONREPORT_BUTTONSTATUS.containing_type = _LABEACONSUMMARY_LABEACONREPORT
_LABEACONSUMMARY.fields_by_name['reports'].message_type = _LABEACONSUMMARY_LABEACONREPORT
DESCRIPTOR.message_types_by_name['IBeaconSummary'] = _IBEACONSUMMARY
DESCRIPTOR.message_types_by_name['TempBeaconSummary'] = _TEMPBEACONSUMMARY
DESCRIPTOR.message_types_by_name['LABeaconSummary'] = _LABEACONSUMMARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IBeaconSummary = _reflection.GeneratedProtocolMessageType('IBeaconSummary', (_message.Message,), {

  'IBeaconReport' : _reflection.GeneratedProtocolMessageType('IBeaconReport', (_message.Message,), {
    'DESCRIPTOR' : _IBEACONSUMMARY_IBEACONREPORT,
    '__module__' : 'c3loc.proto.location_pb2'
    # @@protoc_insertion_point(class_scope:IBeaconSummary.IBeaconReport)
    })
  ,
  'DESCRIPTOR' : _IBEACONSUMMARY,
  '__module__' : 'c3loc.proto.location_pb2'
  # @@protoc_insertion_point(class_scope:IBeaconSummary)
  })
_sym_db.RegisterMessage(IBeaconSummary)
_sym_db.RegisterMessage(IBeaconSummary.IBeaconReport)

TempBeaconSummary = _reflection.GeneratedProtocolMessageType('TempBeaconSummary', (_message.Message,), {

  'TempBeaconReport' : _reflection.GeneratedProtocolMessageType('TempBeaconReport', (_message.Message,), {
    'DESCRIPTOR' : _TEMPBEACONSUMMARY_TEMPBEACONREPORT,
    '__module__' : 'c3loc.proto.location_pb2'
    # @@protoc_insertion_point(class_scope:TempBeaconSummary.TempBeaconReport)
    })
  ,
  'DESCRIPTOR' : _TEMPBEACONSUMMARY,
  '__module__' : 'c3loc.proto.location_pb2'
  # @@protoc_insertion_point(class_scope:TempBeaconSummary)
  })
_sym_db.RegisterMessage(TempBeaconSummary)
_sym_db.RegisterMessage(TempBeaconSummary.TempBeaconReport)

LABeaconSummary = _reflection.GeneratedProtocolMessageType('LABeaconSummary', (_message.Message,), {

  'LABeaconReport' : _reflection.GeneratedProtocolMessageType('LABeaconReport', (_message.Message,), {
    'DESCRIPTOR' : _LABEACONSUMMARY_LABEACONREPORT,
    '__module__' : 'c3loc.proto.location_pb2'
    # @@protoc_insertion_point(class_scope:LABeaconSummary.LABeaconReport)
    })
  ,
  'DESCRIPTOR' : _LABEACONSUMMARY,
  '__module__' : 'c3loc.proto.location_pb2'
  # @@protoc_insertion_point(class_scope:LABeaconSummary)
  })
_sym_db.RegisterMessage(LABeaconSummary)
_sym_db.RegisterMessage(LABeaconSummary.LABeaconReport)


# @@protoc_insertion_point(module_scope)
